"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebpackConfig = void 0;
const tslib_1 = require("tslib");
const fs = (0, tslib_1.__importStar)(require("fs"));
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const webpack_merge_1 = (0, tslib_1.__importDefault)(require("webpack-merge"));
const paths_1 = require("../../lib/paths");
const createWebpackConfig_1 = require("../../lib/createWebpackConfig");
/**
 * Gets the webpack configuration depending on the environment being passed in
 *
 * This also checks for a custom 'webpack.config.override.js' and merges it with the base configuration provided by the library
 * @param environment
 */
function getWebpackConfig(environment) {
    const baseConfig = (0, createWebpackConfig_1.createWebpackConfig)(environment);
    if (fs.existsSync(paths_1.paths.webpackOverride)) {
        console.log(chalk_1.default.cyan('• Using merged webpack.config.override.js'));
        const customConfig = require(paths_1.paths.webpackOverride);
        if (typeof customConfig === 'function') {
            return (0, webpack_merge_1.default)(baseConfig, customConfig(environment === 'development'));
        }
        else if (typeof customConfig === 'object') {
            return (0, webpack_merge_1.default)(baseConfig, require(paths_1.paths.webpackOverride));
        }
        else {
            console.log(chalk_1.default.red('Failed to parse webpack.config.override.js'));
            process.exit(1);
        }
    }
    else {
        return baseConfig;
    }
}
exports.getWebpackConfig = getWebpackConfig;
//# sourceMappingURL=getWebpackConfig.js.map